/**
 * @brief   Device configuration functions for its loading, saving and updating
 * @file    cfg.h
 * @author  Ondrej Jerabek
 */

#ifndef _CFG_H_
#define _CFG_H_

#include <type.h>
#include <rqstat.h>
#include <coremem.h>

#include "ARM_Ethernet_Reader.h"
#include "config.h"

/**
 * @brief   Save configuration specified by parameter cfg_type
 * @param   cfg_type:	Type of configuration which will be saved
 * @return  Nothing
 */
extern void save_configuration(enum e_cfg_type cfg_type);

/**
 * @brief   Load configuration specified by parameter cfg_type
 * @param   cfg_type:	Type of configuration which will be loaded
 * @return  Nothing
 */
extern void load_configuration(enum e_cfg_type cfg_type);

/**
 * @brief   Update all device configurations
 * @return  Nothing
 */
extern void update_configuration(void);

/**
 * @brief   Fix version of configuration specified by parameter cfg_type
 * @param   header:		Pointer to header of configuration
 * @param   cfg_type:	Type of configuration which will be fixed
 * @param   cfg_ver:	Version of configuration
 * @return  Nothing
 */
extern void fix_version(STRUCT_HEADER *header, enum e_cfg_type cfg_type, unsigned char cfg_ver);

#endif // _CFG_H_
