/**
 * @brief   Configuration and macro definitions for libraries
 * @file    config.h
 * @author  Ondrej Jerabek
 *
 * Main configuration and definitions
 */

#ifndef _CONFIG_H_
#define _CONFIG_H_

#define USE_CUTTER_X
#define CORE_MEMORY_EEPROM

#define DEVICE_TYPE					ARFID_ETHERNET_READER
#define FW_VERSION_MAJ				1
#define FW_VERSION_MIN				2
#define FW_VERSION_PATCH			0
#define FW_VERSION_SUFFIX
#define FW_VERSION					FW v%d.%02d
#define HW_VERSION					HW v%d.%02d

#define INFO_SIZE					50

//#define OSCILLATOR				OSC_MAIN
#define SYS_CLK						96000000
#define CRYSTAL_FREQ				19200000UL
#define RTC_CRYSTAL_FREQ			32768UL
#define MS_TICK						(SystemCoreClock / 1000)
//#define USE_PLL

#define MAX_PACKET_DATA_SIZE		256

// EEPROM
#include "eeprom.h"
#define USE_STD_EEPROM
#define STD_EEPROM_SIZE				4032
#define LOG_EEPROM_ADDR				0x00C0
#define LOG_SIZE					20
#define	CFG_EEPROM_ADDR				0x0020
#define CFG_MODULE_ADDR				0x0100
#define CFG_MODULE2_OFFSET			0x0100
#define	CFG_SX_OFFSET				0x0000
#define	CFG_NTR_OFFSET				0x0055
#define	CFG_DW_OFFSET				0x00AA

// Ext Flash
#define EXTFLASH_SIZE		    	2097152
#define USE_EXT_FLASH
#define SYSTEM_EXT
#define SYSTEM_EXT_USE_EXTFLASH
#define FLASHING_BOTTOM				0
#define EXTFLASH_WAIT_FOR_WRITE		1
#define EXTFLASH_WAIT_FOR_ERASE		0
#define FLASHING_TOP				524288

// SPI
#define USE_SPI_WRAPPER
#define FLASH_SPI					0
#define EEPROM_SPI					0
#define MODULES_SPI					1
#define NTRX_SPI					1
#define SPI_0_FREQ					10000000	// 10 MHz
#define SX_SPI1						1
#define SX_SPI2						1
#define SPI_1_FREQ					1000000		// 1 MHz

// UART
#define NO_MULTIMASTER_MODE
#define UART_SYS_BAUD_RATE			57600
#define UART_SYS					3
#define USE_UART_3
#define	UART_3_RXBUFFSIZE			275
#define	UART_3_TXBUFFSIZE			275
#define UART_3_TX(x)
#define UART_3_RX(x)
#define	UART_3_USE_TXEN				0			// 0 - Disable, 1 - Enable Use TX_EN pin (for RS485)
#define UART_TX_TIMEOUT 			1			// [ms] Timeout between receiving and transmitting
#define UART_NEXT_PCK_TIMEOUT		2			// [ms] Timeout between two send packets
#define UART_RESP_TIMEOUT			1
#define UART_REQ_TIMEOUT			2			// [ms] Timeout after receive packet

#define PRINTF_UART					UART_SYS
#define UART_PRINTF

// SX1211
#define COMM_ISR_FREQ				// Couldn't be published
#define RF_FREQUENCY_1				868300000
#define RF_FREQUENCY_2				867300000
#define RF_BAUD						// Couldn't be published
#define SX_XTAL_FREQ				11059200
#define VCO_TRIM					VCO_TRIM_60
#define SX_USE_CRC
#define SYNCWORD					// Couldn't be published
#define SYNCWORD_LENGTH				// Couldn't be published
#define SX_NUMBER					2
#define USE_SX_RSSI
#define SX_CLKOUT					CLKOUT_ENABLED
#define NO_SX_PCK_ID_GEN

// RTC
#define RTC_TICK_FREQ				1000		// [Hz] Reference frequency for timer interrupt
#define RTC_SYNC_TIMECONST			100			// Time constant for trimming RTC
#define RTC_MAX_DIFF				5			// [s] Maximum deviation for time trimming
#define RTC_SYNC_INTERVAL			10000		// [ms] Sync time interval

// LwIP
#define ETH_PHY 					LAN8720
#define NO_TCP_PCK_SEND_RECEIVE		// Disables function tcp_pck_send_receive
#define TCPSTACK_CONFIG_OFFSET 		0x0080
#define APPS_NAME					"Arfid Ethernet Reader"
#define MY_DEFAULT_HOST_NAME		"arfid"
#define HTTP_NAME_PASS				// Couldn't be published
#define PASW					// Couldn't be published
#define LWIP_UDP_CUTTER_TX			0 // Mark UDP1 as channel 0
#define LWIP_UDP_CUTTER_TX2			1 // Mark UDP2 as channel 1

// Bootloader
#define USE_BOOTLOADER
#define BOOTLOADER_MACRO			tmr.bootloader = 200
#ifdef BOOTLOADER_PROJECT
#define SPI_INDEX					FLASH_SPI
#endif

// Handlers
#define DEV_HANDLER_NEW
#define ANSWER_HANDLER
#define DEV_BROADCAST_HANDLER_NEW
#define NO_PCK_ID_GEN
#define ROUTING_TABLE_ENABLED

// Times / Timeouts
#define ANSWER_TIMEOUT				100			// [ms]
#define RSSI_TABLE_SIZE				100
#define RSSI_TIMEOUT				10			// [s]
#define TIMESYNC_BROADCAST_TIMEOUT	1500		// [ms]

// Battery
#define BATT_LOW_VOLTAGE			3250		// [mV]
#define BATT_CRITICAL_VOLTAGE		3100		// [mV] Minimum voltage for correct working LDOs - if voltage is lower perform shutdown

// Button & LED
#define BTN_POWER_OFF_TIME			5000		// [ms] Minimum button push time for shutdown device
#define BTN_RESET_TIME				500			// [ms] Maximum button push time for perform device reset
#define TMR_LED						100			// [ms] LED blinking period

// ADC
#define AVG_SAMPLES					5
#define V_BATT_CHNL					ADC_CH0
#define V_SUPPLY_CHNL				ADC_CH1
#define V_USB_CHNL					ADC_CH6
#define I_MEAS_CHNL					ADC_CH7
#define DIV_BATT_R1					560.0	// [kR]
#define DIV_BATT_R2					560.0	// [kR]
#define DIV_USB_R1					20.0	// [kR]
#define DIV_USB_R2					10.0	// [kR]
#define DIV_SUPPLY_R1				200.0	// [kR]
#define DIV_SUPPLY_R2				10.0	// [kR]
#define R_ISET						1500.	// [R] Resistor connected to pin ISET on batt. charger
#define ADC_LEVELS					4096.
#define VREF						3000.	// [mV]
#define DIVIDER(R1, R2)				(VREF / (ADC_LEVELS * (R2 / (R1 + R2))))

#include "pindef.h"

// Dallas
#include "interrupt.h"
#define DS_TREG_CHECK
#define DS_DI
#define ds_di()						di()
#define ds_ei()						ei()
#define ds_dil()					di()
#define ds_eil()					ei()

#define DS_TREG_CHECK
#define DS_DI
#define ds_di()						di()
#define ds_ei()						ei()
#define ds_dil()					di()
#define ds_eil()					ei()

#define dqz()	DS_DIR(0)
#define dqhigh()DS_DIR(1), DS_OUT(1)
#define dqlow()	DS_DIR(1), DS_OUT(0)
#define dq()  	DS_IN

// --------------------------------------------------------------------------
// nanoLOC config (nanotron)

//#define NTRX_EXTERNAL_CLOCK

/* select the time between to nanoLOC TRX chip recalibrations in ms */
#define CONFIG_NTRX_RECAL_DELAY (3000)
//#define CONFIG_NTRX_AUTO_RECALIB 1

/* use auto recalibration */
#ifdef NTRX_RANGER_TEST
#define CONFIG_NTRX_AUTO_RECALIB 1
#endif

/* select the time between last packet and timeout indication in ms */
#define CONFIG_NTRX_PHY_RX_TIMEOUT (5000)
/* use leds for tx/rx indication */
#define CONFIG_TRAFFIC_LED 	1

/* use led for recalibration indication */
#define CONFIG_USE_TX_LED 1
#define CONFIG_USE_RX_LED 1

/* use syncword */
#define CONFIG_DEFAULT_SYNCWORD 	// Couldn't be published

/* All available trx modes */
#define CONFIG_NTRX_22MHZ_4000NS  0x03
#define CONFIG_NTRX_80MHZ_1000NS  0x06
#define CONFIG_NTRX_80MHZ_2000NS  0x07
#define CONFIG_NTRX_80MHZ_4000NS  0x08
#define CONFIG_NTRX_22MHZ_4000NS_ROM  0x0A
#ifndef NTRX_RANGER_TEST
#define CONFIG_DEFAULT_MODE CONFIG_NTRX_80MHZ_4000NS
#else
#define CONFIG_DEFAULT_MODE CONFIG_NTRX_80MHZ_4000NS
#endif
#if 	  (CONFIG_DEFAULT_MODE != (CONFIG_NTRX_22MHZ_4000NS) \
		&& CONFIG_DEFAULT_MODE != (CONFIG_NTRX_80MHZ_1000NS) \
		&& CONFIG_DEFAULT_MODE != (CONFIG_NTRX_80MHZ_4000NS) \
		&& CONFIG_DEFAULT_MODE != (CONFIG_NTRX_22MHZ_4000NS_ROM))
#ifdef CONFIG_NTRX_80MHZ_1000NS
#undef CONFIG_DEFAULT_MODE
#define CONFIG_DEFAULT_MODE CONFIG_NTRX_80MHZ_1000NS
#warning No default mode set. Set to 80Mhz 1us!
#else
#error Please select a default mode in config.h
#endif
#endif

/* Number of retransmissions */
#define CONFIG_MAX_ARQ 		1

/* number of predefined modes */
#define CONFIG_MAX_LOG_CHANNEL	4

/* payload size */
#define CONFIG_MAX_PACKET_SIZE 128

#define NTRXRANGING_SELECT_TYPES
#define SUPPORT_RANGING_TYPE_3W_A


// --------------------------------------------------------------------------
#define NTRX_COUNT				2
//#define NTRX_ENCRYPT_PACKETS
//#define NTRX_BEACON_CONTINUAL

// --------------------------------------------------------------------------
// USB
/**
 * LPCUSBLib:
 * Microcontroller architecture: ARCH_LPC (Chip architecture. Must be ARCH_LPC)
 * Microcontroller model: __LPC11UXX__, __LPC13UXX__, __LPC17XX__, __LPC177X_8X__, __LPC18XX__, __LPC43XX__ (see USBMode.h)
 * nxpUSBlib mode configuration: USB_DEVICE_ONLY (Build only device related code in the USB library), USB_HOST_ONLY (Build only host related code in the USB library)
 *
 * USB_FORCED_FULLSPEED  1/0: 1 - operate ALWAYS in USB Full-Speed (12 Mbit/s) although some MCU can support USB Hi-Speed (480 Mbit/s), 0 - use max supported USB speed
 * USE_USB_ROM_STACK  1/0: 1 - use MCU's internal ROM USB stack (only some MCU), 0 - no USB ROM stack
 * USB_PORT  0/1/0xFF: 0 - use USB0, 1 - use USB1, 0xFF - MultiPort (all (or rather both) supported USB peripherals)
 */
#define USE_USB_PLL				// USB clock source
#define USB_DEVICE_ONLY			// LPCUSBLib: USB_HOST_ONLY or USB_DEVICE_ONLY
#define USB_UP_LED				// GoodLink: When the host/device is successfully enumerated and configured, the LED indicator will be permanently ON. During suspend, the LED will be OFF.
#define USB_SOFT_CONNECT		// USB SoftConnect (device only): use software control D+ (full-speed device) through a 1.5kOhm EXTERNAL pull-up resistor in initialisation sequence
#define USB_SOFT_CONNECT_TIMER	3000
//#define USB_MONITOR_VBUS		// VBUS monitor (device only): Monitor the presence of USB bus power
//#define USB_FORCED_FULLSPEED	0  // use max supported USB speed
//#define USE_USB_ROM_STACK		1  // use MCU's internal ROM USB stack (only some MCU)
//#define USB_PORT				0  // use USB0
//#define USB_VID					0x1fc9  // VendorID - NXP
//#define USB_PID					0x2042  // ProductID
//#define MANUFACTURER_STRING	"NXP"  // Manufacturer descriptor string (should be relevant to VendorID!!! (VendorID = 0x1fc9 -> Manufacturer = "NXP"))
#define PRODUCT_STRING		"Ethernet Reader"  // Product descriptor string

#endif // CONFIG_H
