/**
 * @brief   Modules control
 * @file    modules.h
 * @author  Ondrej Jerabek
 *
 */

#ifndef MODULE_H_
#define MODULE_H_

#include <pck.h>

/**
 * @brief 	Index of selected module
 */
enum e_module
{
	MODULE_1,		/**< Module 1 selection */
	MODULE_2,		/**< Module 2 selection */
};


/**
 * @brief 	Module type connected in slot
 */
enum e_module_type
{
	MODULE_OFF,			/**< Module off */
	MODULE_NOT_INIT,	/**< Module not initialized */
	MODULE_NONE,		/**< No module in slot */
	MODULE_SX,			/**< Semtech module present */
	MODULE_NTR,			/**< Nanotron module present */
	MODULE_DW,			/**< Decawave module present */
};

/**
 * @brief 	Module state in each slot
 */
typedef struct
{
	enum e_module_type slot1_type;		/**< Module state in slot 1 */
	enum e_module_type slot2_type;		/**< Module state in slot 2 */
} MODULE_STRUCT;

// --------------------------------------------------------------------------
extern MODULE_STRUCT modules;

// --------------------------------------------------------------------------
/**
 * @brief   	Initialize all modules in slots
 * @return  	Nothing
 */
extern void modules_init(void);

/**
 * @brief   	Sending packet through selected module
 * @param		module:		Module index
 * @param[in]	pck:		Pointer to packet which will be send through selected module
 * @return  	Nothing
 */
extern void module_pck_send(enum e_module module, TPacket *pck);

/**
 * @brief   	Sending and receiving packet through selected module
 * @param		module:		Module index
 * @param[in]	pckin:		Pointer to packet which will be send through selected module
 * @param[out]	pckout:		Pointer to packet buffer where will be put received packet
 * @param		timeout:	Timeout for answer waiting in milliseconds
 * @return  	Result of sending or receiveing packet
 */
extern enum e_send_receive_status module_pck_send_receive(enum e_module module, TPacket *pckin, TPacket *pckout, unsigned char timeout);

/**
 * @brief   	Measuring Receive Signal Strength Intensity of received packet
 * @param		module:		Module index
 * @return  	Received signal strength
 * @note		Implemented only on Semtech module
 */
extern unsigned char module_get_rssi(enum e_module module);

/**
 * @brief   	Measuring Receive Signal Strength Intensity of background
 * @param		module:		Module index
 * @return  	Received signal strength
 * @note		Implemented only on Semtech module and Nanotron module
 */
extern unsigned char module_get_rssi_background(enum e_module module);

#endif /* MODULE_H_ */
