/**
 * @file   pindef.c
 * @author Ondrej Jerabek
 */

#include "config.h"
#include <chip.h>
#include "iocon_17xx_40xx.h"
#include "gpioint_17xx_40xx.h"
#include "spi_wrapper.h"
#include "uart_wrapper.h"
#include "main.h"


// --------------------------------------------------------------------------
/**
 * @brief 	Default pin modes
 */
STATIC const PINMUX_GRP_T pinmuxing[] = {
	{SCK0_PIO0_15},		// SPI0 - SCK
	{MISO0_PIO0_17},	// SPI0 - MISO
	{MOSI0_PIO0_18},	// SPI0 - MOSI

	{SCK1_PIO0_7 | IOCON_DIGMODE_EN},		// SPI1 - SCK
	{MISO1_PIO0_8 | IOCON_MODE_PULLUP | IOCON_DIGMODE_EN},		// SPI1 - MISO
	{MOSI1_PIO0_9 | IOCON_DIGMODE_EN},		// SPI1 - MOSI

	{TXD3_PIO0_25},		// UART3 - TXD
	{RXD3_PIO0_26},		// UART3 - RXD

	{0, 31, IOCON_FUNC1},	// USB2 - D+
	{0, 14, IOCON_FUNC3},	// USB2 - CON

	{1, 27, IOCON_FUNC4},	// CLKOUT

	{1, 0, IOCON_FUNC1},	// PHY - TXD0
	{1, 1, IOCON_FUNC1},	// PHY - TXD1
	{1, 4, IOCON_FUNC1},	// PHY - TXEN
	{1, 8, IOCON_FUNC1},	// PHY - CRS
	{1, 9, IOCON_FUNC1},	// PHY - RXD0
	{1, 10, IOCON_FUNC1},	// PHY - RXD1
	{1, 14, IOCON_FUNC1},	// PHY - RXER
	{1, 15, IOCON_FUNC1},	// PHY - REF_CLK
	{1, 16, IOCON_FUNC1},	// PHY - MDC
	{1, 17, IOCON_FUNC1 | IOCON_MODE_INACT | IOCON_DIGMODE_EN | IOCON_OPENDRAIN_EN | IOCON_FILT_DIS},	// PHY - MDIO

	{0, 19, IOCON_FUNC2},	// SD - CLK
	{0, 20, IOCON_FUNC2},	// SD - CMD
	{0, 22, IOCON_FUNC2},	// SD - DAT0
	{2, 11, IOCON_FUNC2},	// SD - DAT1
	{2, 12, IOCON_FUNC2},	// SD - DAT2
	{2, 13, IOCON_FUNC2},	// SD - DAT3

	{3, 0, IOCON_FUNC1},	// EMC - D0
	{3, 1, IOCON_FUNC1},	// EMC - D1
	{3, 2, IOCON_FUNC1},	// EMC - D2
	{3, 3, IOCON_FUNC1},	// EMC - D3
	{3, 4, IOCON_FUNC1},	// EMC - D4
	{3, 5, IOCON_FUNC1},	// EMC - D5
	{3, 6, IOCON_FUNC1},	// EMC - D6
	{3, 7, IOCON_FUNC1},	// EMC - D7
	{4, 0, IOCON_FUNC1},	// EMC - A0
	{4, 1, IOCON_FUNC1},	// EMC - A1
	{4, 2, IOCON_FUNC1},	// EMC - A2
	{4, 3, IOCON_FUNC1},	// EMC - A3
	{4, 4, IOCON_FUNC1},	// EMC - A4
	{4, 5, IOCON_FUNC1},	// EMC - A5
	{4, 6, IOCON_FUNC1},	// EMC - A6
	{4, 7, IOCON_FUNC1},	// EMC - A7
	{4, 8, IOCON_FUNC1},	// EMC - A8
	{4, 9, IOCON_FUNC1},	// EMC - A9
	{4, 10, IOCON_FUNC1},	// EMC - A10
	{4, 11, IOCON_FUNC1},	// EMC - A11
	{4, 12, IOCON_FUNC1},	// EMC - A12
	{4, 13, IOCON_FUNC1},	// EMC - A13
	{4, 14, IOCON_FUNC1},	// EMC - A14
	{4, 15, IOCON_FUNC1},	// EMC - A15
	{4, 24, IOCON_FUNC1},	// EMC - OE
	{4, 25, IOCON_FUNC1},	// EMC - WE
	{4, 30, IOCON_FUNC1},	// EMC - CS0 => connected to A16

	{0, 23, IOCON_FUNC1},	// ADC - CH0 => V_BATT
	{0, 24, IOCON_FUNC1},	// ADC - CH1 => V_SUPPLY
	{0, 12, IOCON_FUNC3},	// ADC - CH6 => V_USB
	{0, 13, IOCON_FUNC3},	// ADC - CH7 => I_MEAS
};

// --------------------------------------------------------------------------

/**
 * @brief 	Initialize default pin state and mode
 * @return	Nothing
 */
void pindef_init(void)
{
	INIT_IO();

	Chip_IOCON_Init(LPC_IOCON);
	Chip_GPIOINT_Init(LPC_GPIOINT);
	Chip_IOCON_SetPinMuxing(LPC_IOCON, pinmuxing, sizeof(pinmuxing) / sizeof(PINMUX_GRP_T));
}
// --------------------------------------------------------------------------

