/**
 * @brief   Receive Signal Strength Intensity Table
 * @file    rssi.h
 * @author  Ondrej Jerabek
 */

#ifndef RSSI_H_
#define RSSI_H_

#include <type.h>
#include "config.h"

#define RSSI_NOT_SUPPORTED		255

/**
 * @brief RSSI table item structure
 */
typedef struct
{
	unsigned int addr;			/**< Device address 						*/
	unsigned char rssi[2];		/**< RSSI for each module 					*/
	unsigned char timer[2];		/**< timer for item timeout for each module	*/
} rssi_table_t;

// --------------------------------------------------------------------------
extern rssi_table_t rssi_table[RSSI_TABLE_SIZE];

// --------------------------------------------------------------------------
/**
 * @brief   Handle timers of the items in table
 * @return  Nothing
 * @note	Should be called each second
 */
extern void rssi_table_tick(void);

/**
 * @brief   Adding item to RSSI table
 * @param	addr:		Device address
 * @param	module:		Module which received packet
 * @param	rssi:		Received packet RSSI
 * @return  Nothing
 */
extern void rssi_table_add(unsigned int addr, unsigned char module, unsigned char rssi);

/**
 * @brief   Put RSSI table to buffer (Prepare it for send)
 * @param	buffer:			Pointer to buffer where RSSI table will be copied
 * @param	index:			Index in RSSI table where the copying starts
 * @param	max_rec_cnt:	Maximum number of items copied to buffer
 * @return  Occupied size in bytes
 */
unsigned char rssi_table_get(unsigned char *buffer, unsigned char index, unsigned char max_rec_cnt);

#endif /* RSSI_H_ */
