/**
 * @brief   Wrapper for using more SPIs
 * @file    spi_wrapper.h
 * @author  Ondrej Jerabek
 */

#ifndef _SPI_WRAPPER
#define _SPI_WRAPPER

#if defined(__LPC407X_8X__)

/**
 * @brief	Pin definitions for enabling SPI functionality
 */
#define SCK0_PIO0_15				0, 15, IOCON_FUNC2
#define SCK0_PIO1_20				1, 20, IOCON_FUNC5
#define SCK0_PIO2_22				2, 22, IOCON_FUNC2
#define MISO0_PIO0_17				0, 17, IOCON_FUNC2
#define MISO0_PIO1_23				1, 23, IOCON_FUNC5
#define MISO0_PIO2_26				2, 26, IOCON_FUNC2
#define MOSI0_PIO0_18				0, 18, IOCON_FUNC2
#define MOSI0_PIO1_24				1, 24, IOCON_FUNC5
#define MOSI0_PIO2_27				2, 27, IOCON_FUNC2

#define SCK1_PIO0_7					0, 7, IOCON_FUNC2
#define SCK1_PIO1_19				1, 19, IOCON_FUNC5
#define SCK1_PIO1_31				1, 31, IOCON_FUNC2
#define SCK1_PIO4_20				4, 20, IOCON_FUNC3
#define MISO1_PIO0_8				0, 8, IOCON_FUNC2 | IOCON_DIGMODE_EN
#define MISO1_PIO0_12				0, 12, IOCON_FUNC2
#define MISO1_PIO1_18				1, 18, IOCON_FUNC5
#define MISO1_PIO4_22				4, 22, IOCON_FUNC3
#define MOSI1_PIO0_9				0, 9, IOCON_FUNC2
#define MOSI1_PIO0_13				0, 13, IOCON_FUNC2
#define MOSI1_PIO1_22				1, 22, IOCON_FUNC5
#define MOSI1_PIO4_23				4, 23, IOCON_FUNC3

#define SCK2_PIO1_0					1, 0, IOCON_FUNC4
#define MISO2_PIO1_4				1, 4, IOCON_FUNC4
#define MOSI2_PIO1_1				1, 1, IOCON_FUNC4

#endif // __LPC407X_8X__

// --------------------------------------------------------------------------
#define __SPI(index, name)			SPI_##index##_##name
#define _SPI(index, name)			__SPI(index, name)

#define SPI_FREQ					_SPI(SPI_INDEX, FREQ)
// --------------------------------------------------------------------------
// Declaration function
#ifndef spi_init
#define spi_init()					SPI_Master_Init(SPI_INDEX, SPI_FREQ)
#endif
#ifndef spi_write
#define spi_write(data)				SPI_Write(SPI_INDEX, data)
#endif
#ifndef spi_read_write
#define spi_read_write(data)		SPI_Read_Write(SPI_INDEX, data)
#endif
#ifndef spi_read
#define spi_read()					SPI_Read_Write(SPI_INDEX, 0x00)
#endif
#ifndef spi_wait_busy
#define spi_wait_busy()				SPI_Wait_Busy(SPI_INDEX)
#endif

#ifdef __cplusplus
extern "C" {
#endif

// --------------------------------------------------------------------------
/**
 * @brief   Initialize SPI in Master mode
 * @param	index:		Index of SPI peripheral
 * @param	freq:		Frequency of SPI clk
 * @return  Nothing
 */
extern void SPI_Master_Init(unsigned char index, unsigned int freq);

/**
 * @brief   Send data through SPI
 * @param	index:		Index of SPI peripheral
 * @param	data:		Data to send
 * @return  Nothing
 */
extern void SPI_Write(unsigned char index, unsigned short data);

/**
 * @brief   Send and receive data through SPI
 * @param	index:		Index of SPI peripheral
 * @param	data:		Data to send
 * @return  Read data
 */
extern unsigned short SPI_Read_Write(unsigned char index, unsigned short data);

/**
 * @brief   Waiting for complete SPI transfer
 * @param	index:		Index of SPI peripheral
 * @return  Nothing
 */
extern void SPI_Wait_Busy(unsigned char index);

#ifdef __cplusplus
} // extern "C"
#endif

#endif // _SPI_WRAPPER
